@@ -23,22 +23,22 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class CreateCostUnitRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateCostUnit')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateCostUnit','bssopenapi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_UnitEntityList(self):
+	def get_UnitEntityLists(self): # RepeatList
 		return self.get_query_params().get('UnitEntityList')
 
-	def set_UnitEntityList(self, UnitEntityLists):
-		for depth1 in range(len(UnitEntityLists)):
-			if UnitEntityLists[depth1].get('UnitName') is not None:
-				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.UnitName', UnitEntityLists[depth1].get('UnitName'))
-			if UnitEntityLists[depth1].get('ParentUnitId') is not None:
-				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.ParentUnitId', UnitEntityLists[depth1].get('ParentUnitId'))
-			if UnitEntityLists[depth1].get('OwnerUid') is not None:
-				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.OwnerUid', UnitEntityLists[depth1].get('OwnerUid'))
\ No newline at end of file
+	def set_UnitEntityLists(self, UnitEntityList):  # RepeatList
+		for depth1 in range(len(UnitEntityList)):
+			if UnitEntityList[depth1].get('UnitName') is not None:
+				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.UnitName', UnitEntityList[depth1].get('UnitName'))
+			if UnitEntityList[depth1].get('ParentUnitId') is not None:
+				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.ParentUnitId', UnitEntityList[depth1].get('ParentUnitId'))
+			if UnitEntityList[depth1].get('OwnerUid') is not None:
+				self.add_query_param('UnitEntityList.' + str(depth1 + 1) + '.OwnerUid', UnitEntityList[depth1].get('OwnerUid'))
